/*
    *
    * This file is a part of CoreImage.
    * An image viewer for CuboCore Application Suite
    * Copyright 2019 CuboCore Group
    *

    *
    * This program is free software; you can redistribute it and/or modify
    * it under the terms of the GNU General Public License as published by
    * the Free Software Foundation; either version 2 of the License, or
    * (at your option) any later version.
    *

    *
    * This program is distributed in the hope that it will be useful,
    * but WITHOUT ANY WARRANTY; without even the implied warranty of
    * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    * GNU General Public License for more details.
    *

    *
    * You should have received a copy of the GNU General Public License
    * along with this program; if not, write to the Free Software
    * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
    * MA 02110-1301, USA.
    *
*/

#ifndef COREIMAGE_H
#define COREIMAGE_H

#include <QWidget>
#include <QImage>
#include <QLabel>
#include <QFileDialog>
#include <QCloseEvent>

#include <cprime/settingsmanage.h>


class QListWidgetItem;
class QSpacerItem;
class QTimer;
class QScrollBar;

namespace Ui {
	class coreimage;
}

class coreimage : public QWidget {

	Q_OBJECT

public:
	explicit coreimage(QWidget *parent = nullptr);
	~coreimage();

	void sendFiles(const QStringList &paths);
    bool loadImage(QString filePath);

protected:
	void closeEvent(QCloseEvent *event);

private:
	Ui::coreimage  *ui;
    QLabel *zoomLbl;

    settingsManage *sm = settingsManage::initialize();

    QString workFilePath;
    bool sideView, touch, slideShow, tabletMode;
    int sideViewSize;
    QSize sideViewIconSize, toolBarIconSize;
    QTimer *slideShowTimer;
    QStringList imagesList;

    QStringList openFilters;
    QStringList saveFilters;

    void loadSettings();
    void startMode();
    void startSetup();
    void shortcuts();
    void getImageFilters();
    void initializeImageFileDialog(QFileDialog &dialog, QFileDialog::AcceptMode acceptMode);
    void enableButtons(bool enable);
    void getImagesForOpenedImage();

private slots:
    void on_cSave_clicked();
    void on_cSaveAs_clicked();
    void on_rotate_clicked();
    void on_openInEditor_clicked();
    void on_openmetadataApp_clicked();
    void on_containingFolder_clicked();
    void on_cTrashIt_clicked();
    void on_shearIt_clicked();
    void on_pinIt_clicked();
    void on_slideShow_clicked(bool checked);
    void previousItem();
    void nextItem();
    void openFileDialog();
    void showSideView();
    void changeZoomLabel();
    void closeSlideShow();

};

#endif // COREIMAGE_H
